<?php
/*
 * Copyright (c) 2018-2021 Atipay, (https://www.atipay.net)

 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * */
class ControllerPaymentAtipay extends Controller {
    private $error = array();

    public function index() {
        $this->load->language('payment/atipay');

        $this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('setting/setting');

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
            $this->model_setting_setting->editSetting('atipay', $this->request->post);

            $this->session->data['success'] = $this->language->get('text_success');

            $this->response->redirect($this->url->link('extension/payment', 'token=' . $this->session->data['token'], 'SSL'));
        }

        $data['heading_title'] = $this->language->get('heading_title');

        $data['text_edit'] = $this->language->get('text_edit');
        $data['text_enabled'] = $this->language->get('text_enabled');
        $data['text_disabled'] = $this->language->get('text_disabled');
        $data['text_all_zones'] = $this->language->get('text_all_zones');
        $data['text_yes'] = $this->language->get('text_yes');
        $data['text_no'] = $this->language->get('text_no');
        $data['text_authorization'] = $this->language->get('text_authorization');
        $data['text_sale'] = $this->language->get('text_sale');
        $data['text_rial'] = $this->language->get('text_rial');
        $data['text_toman'] = $this->language->get('text_toman');

        $data['entry_apikey'] = $this->language->get('entry_apikey');
        $data['entry_currency'] = $this->language->get('entry_currency');
        $data['entry_order_status'] = $this->language->get('entry_order_status');
        $data['entry_order_failed_status'] = $this->language->get('entry_order_failed_status');




        $data['entry_canceled_reversal_status'] = $this->language->get('entry_canceled_reversal_status');
        $data['entry_completed_status'] = $this->language->get('entry_completed_status');
        $data['entry_denied_status'] = $this->language->get('entry_denied_status');
        $data['entry_expired_status'] = $this->language->get('entry_expired_status');
        $data['entry_failed_status'] = $this->language->get('entry_failed_status');
        $data['entry_pending_status'] = $this->language->get('entry_pending_status');
        $data['entry_processed_status'] = $this->language->get('entry_processed_status');
        $data['entry_refunded_status'] = $this->language->get('entry_refunded_status');
        $data['entry_reversed_status'] = $this->language->get('entry_reversed_status');
        $data['entry_voided_status'] = $this->language->get('entry_voided_status');


        $data['entry_status'] = $this->language->get('entry_status');
        $data['entry_sort_order'] = $this->language->get('entry_sort_order');


        $data['help_apikey'] = $this->language->get('help_apikey');
        $data['help_currency'] = $this->language->get('help_currency');
        $data['help_order_status'] = $this->language->get('help_order_status');
        $data['help_order_failed_status'] = $this->language->get('help_order_failed_status');
        $data['help_debug'] = $this->language->get('help_debug');


        $data['button_save'] = $this->language->get('button_save');
        $data['button_cancel'] = $this->language->get('button_cancel');

        $data['tab_general'] = $this->language->get('tab_general');
//        $data['tab_status'] = $this->language->get('tab_status');

        if (isset($this->error['warning'])) {
            $data['error_warning'] = $this->error['warning'];
        } else {
            $data['error_warning'] = '';
        }


        if (isset($this->error['apikey'])) {
            $data['error_apikey'] = $this->error['apikey'];
        } else {
            $data['error_apikey'] = '';
        }

        if (isset($this->error['currency'])) {
            $data['error_currency'] = $this->error['currency'];
        } else {
            $data['error_currency'] = '';
        }
        $data['breadcrumbs'] = array();

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/home', 'token=' . $this->session->data['token'], 'SSL')
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_payment'),
            'href' => $this->url->link('extension/payment', 'token=' . $this->session->data['token'], 'SSL')
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('payment/atipay', 'token=' . $this->session->data['token'], 'SSL')
        );

        $data['action'] = $this->url->link('payment/atipay', 'token=' . $this->session->data['token'], 'SSL');

        $data['cancel'] = $this->url->link('extension/payment', 'token=' . $this->session->data['token'], 'SSL');


        if (isset($this->request->post['atipay_apikey'])) {
            $data['atipay_apikey'] = $this->request->post['atipay_apikey'];
        } else {
            $data['atipay_apikey'] = $this->config->get('atipay_apikey');
        }

        if (isset($this->request->post['atipay_currency'])) {
            $data['atipay_currency'] = $this->request->post['atipay_currency'];
        } else {
            $data['atipay_currency'] = $this->config->get('atipay_currency');
        }

        if (isset($this->request->post['atipay_order_status'])) {
            $data['atipay_order_status'] = $this->request->post['atipay_order_status'];
        } else {
            $data['atipay_order_status'] = $this->config->get('atipay_order_status');
        }

        if (isset($this->request->post['atipay_order_failed_status'])) {
            $data['atipay_order_failed_status'] = $this->request->post['atipay_order_failed_status'];
        } else {
            $data['atipay_order_failed_status'] = $this->config->get('atipay_order_failed_status');
        }


        $this->load->model('localisation/order_status');
        $data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();


        if (isset($this->request->post['atipay_status'])) {
            $data['atipay_status'] = $this->request->post['atipay_status'];
        } else {
            $data['atipay_status'] = $this->config->get('atipay_status');
        }

        if (isset($this->request->post['atipay_sort_order'])) {
            $data['atipay_sort_order'] = $this->request->post['atipay_sort_order'];
        } else {
            $data['atipay_sort_order'] = $this->config->get('atipay_sort_order');
        }

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('payment/atipay.tpl', $data));
    }

    private function validate() {
        if (!$this->user->hasPermission('modify', 'payment/atipay')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }

        if (!$this->request->post['atipay_apikey']) {
            $this->error['apikey'] = $this->language->get('error_apikey');
        }

        if (!$this->request->post['atipay_currency']) {
            $this->error['currency'] = $this->language->get('error_currency');
        }

        return !$this->error;
    }
}