<?php
/*
 * Copyright (c) 2018-2021 Atipay, (https://www.atipay.net)

 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * */


require_once  DIR_SYSTEM . '/library/atipay/core/fn.atipay.php';
class ControllerPaymentAtipay extends Controller
{
    public function index()
    {
        $this->language->load('payment/atipay');
        $data['atipay_redirect_url'] = ATIPAY_REDIRECT_TO_PSP_URL;
        $data['text_btn_button']= $this->language->get('text_button_payment');
        $data['text_loading']= $this->language->get('text_loading');

        if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/payment/atipay.tpl')) {
            return $this->load->view($this->config->get('config_template') . '/template/payment/atipay.tpl', $data);
        } else {
            return $this->load->view('default/template/payment/atipay.tpl', $data);
        }
    }



    public function token()
    {
        $result = array();


        $this->language->load('payment/atipay');
        $this->load->model('checkout/order');
        $data['text_btn_button']= $this->language->get('button_payment');
        $order_info = $this->model_checkout_order->getOrder($this->session->data['order_id']);
        $apikey = $this->config->get('atipay_apikey');
        $store_cur = $this->config->get('atipay_currency');

        $amount = $order_info['total'];
        $order_id = $order_info['order_id'];
        $first_name = $order_info['firstname'];
        $last_name = $order_info['lastname'];
        $store = $order_info['store_name'];

        if ($store_cur == "T") {
            $amount = $amount * 10;
        }else{
            $amount = $amount * 1;
        }
        $callback =  $this->url->link('payment/atipay/callback&order_id=' . $order_id);
        $token_params = array(
            'apiKey'=>$apikey,
            'redirectUrl'=>$callback,
            'invoiceNumber'=>$order_id,
            'amount'=>$amount,
//            'cellNumber'=>$mobile,
            'description'=>$store . '-' . $order_id,
            'buyerName'=>$first_name . ' ' . $last_name,
        );
        $data['token_params']=$token_params;
        $r = fn_atipay_get_token($token_params);
        $data['r']=$r;
        if ($r['success'] == 1){
            $result['success']=true;
            $result['token']=$r['token'];
        }else{
            $error_message = $r['errorMessage'];
            $data['atipay_error'] = $error_message;
            $result['success']=false;
            $result['errorMessage']=$error_message;

        }
        @$this->response->setOutput(json_encode($result));

    }

    public function callback()
    {
        $this->language->load('payment/atipay');
        if (!$this->request->server['HTTPS']) {
            $data['base'] = $this->config->get('config_url');
        } else {
            $data['base'] = $this->config->get('config_ssl');
        }


        $params = $this->request->post;
        $result = fn_check_callback_data($params);
        $atipay_order_status = $this->config->get('atipay_order_status');
        $atipay_order_failed_status =$this->config->get('atipay_order_failed_status');

        $order_id = $params['reservationNumber'];
        $this->load->model('checkout/order');

        $order_info = $this->model_checkout_order->getOrder($order_id);
        $amount = $order_info['total'];
        $store_cur = $this->config->get('atipay_currency');

        if ($store_cur == "T") {
            $amount = $amount * 10;
        }else{
            $amount = $amount * 1;
        }
        $data['payment_result'] = 'F';
        if ($order_info){
            if ($result['success'] == 1) { //will verify here
                $apikey = $this->config->get('atipay_apikey');
                $verify_params = array('apiKey'=>$apikey,
                    'referenceNumber'=>$params['referenceNumber']
                );
                $vr = fn_atipay_verify_payment($verify_params,$amount);
                if ($vr['success'] == 0){ //veriy failed
                    $error_message = $vr['errorMessage'];
                    $data['continue'] = $this->url->link('checkout/cart');
                    $data['error_message']=$error_message;
                    $this->model_checkout_order->addOrderHistory($order_id, $atipay_order_failed_status, $error_message);
                }else{
                    $data['payment_result'] = 'S';
                    $data['success_message'] =  $this->language->get('text_success_payment');;
                    $data['continue'] = $this->url->link('checkout/success');
                    $this->model_checkout_order->addOrderHistory($order_id, $atipay_order_status, "Reference Number: " . $params['referenceNumber'] .  " Tracking Number: " . $params['traceNumber']);
                }

            }else{
                $data['continue'] = $this->url->link('checkout/cart');
                $error_message = $result['error'];
                $data['error_message']=$error_message;
                $this->model_checkout_order->addOrderHistory($order_id, $atipay_order_failed_status, $error_message);
            }
        }

        if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/payment/atipay_result.tpl')) {
            $this->response->setOutput($this->load->view($this->config->get('config_template') . '/template/payment/atipay_result.tpl', $data));
        } else {
            $this->response->setOutput($this->load->view('default/template/payment/atipay_result.tpl', $data));
        }
    }
}